from .base_dir import *
from .media_dir import *
from .users_dir import *
UPLOADS_DIR = "/var/www/media/uploads"
TEMP_DIR = "/var/www/media/temp"
UTILS_URL_PREFIX = '/utilities/'
API_URL_PREFIX = '/api/'
MEDIA_URL_PREFIX = '/media/'
SECURE_FILES_PREFIX = f"/secure-files/"
STATIC_FOLDER = PUBLIC_USER_DIR
TEMPLATES_FOLDER = "/var/www/api/abstract_logins/app/src/templates"
ABS_HTML_AUTHS_FOLDER = TEMPLATES_FOLDER
